# A python-based UI module for iolite 4 starts with some metadata
#/ Type: UI
#/ Name: ActiveSplit
#/ Description: Splits the active selection
#/ Authors: J. Petrus
#/ References:
#/ Version: 1.0
#/ Contact:

from iolite.QtGui import QAction, QMessageBox, QKeySequence

def createUIElements():
	action = QAction('Split the active selection', None)
	action.triggered.connect(split)
	action.setShortcut(QKeySequence('Alt+1'))
	ui.setAction(action)
	ui.setMenuName(['Tools', 'Joe\'s scripts'])

def split():
	s = data.activeSelection() # Get the active selection
	if s is None:
		QMessageBox.information(None, 'Split', 'There is no active selection. Abort!')
		return
	
	N = 50 # Set the number of selections to split into
	dest_group = data.createSelectionGroup(f'{s.name} split{N}', data.Sample, True) # Create a group called split

	# Calculate the duration of each sub-selection
	dur = (s.endTime.toMSecsSinceEpoch() - s.startTime.toMSecsSinceEpoch())/(1000.0*N)

	ps = None # Used to keep track of previous selection

	# Work out the start and end time for each sub-selection and add it to the group
	for i in range(0, N):
		if not ps:
			this_start = s.startTime
		else:
			this_start = ps.endTime

		this_end = this_start.addMSecs(1000.0*dur)
		ps = data.createSelection(dest_group, this_start, this_end, 'Split%i'%(i))


