# A python-based UI module for iolite 4 starts with some metadata
#/ Type: UI
#/ Name: CellView
#/ Description: Plots selections in cell space
#/ Authors: J. Petrus
#/ References:
#/ Version: 1.0
#/ Contact:


from iolite.QtGui import QDockWidget, QWidget, QPainter, QPen, QBrush, QPixmap
from iolite.QtCore import Qt, QPointF
import numpy as np

class CellView(QWidget):
	def __init__(self, parent=None):
		QWidget.__init__(self, parent)
		self.cellSize = (100000., 100000)
		data.activeSelectionChanged.connect(self.repaint)

	def paintEvent(self, event):
		prect = event.rect().adjusted(5, 5, -5, -5)
		prect.setHeight(prect.width()*self.cellSize[1]/self.cellSize[0])
		p = QPainter(self)
		p.setRenderHint(QPainter.Antialiasing)

		# Draw a rectangle representing the cell
		p.setPen(QPen(Qt.white, 2))
		p.drawRect(prect)

		scale = float(prect.width())/self.cellSize[0]

		for group in data.selectionGroupList(data.Sample | data.ReferenceMaterial):
			if data.activeSelectionGroup() and data.activeSelectionGroup().name == group.name:
				p.setPen(QPen(Qt.green, 1.))
				p.setBrush(QBrush(Qt.green))
			else:
				p.setPen(QPen(Qt.white, 1.))
				p.setBrush(QBrush(Qt.white))

			for sel in group.selections():
				if 'Coords' not in sel.properties():
					continue

				startPoint = sel.property('Coords')[0]
				endPoint = sel.property('Coords')[1]

				sx = startPoint.x()*scale + 5
				sy = startPoint.y()*scale + 5
				ex = endPoint.x()*scale + 5
				ey = endPoint.y()*scale + 5
				spotWidth = sel.property('Spot Width')*scale
				spotHeight = sel.property('Spot Height')*scale

				if spotWidth < 1:
					spotWidth = 1
				if spotHeight < 1:
					spotHeight = 1

				p.drawEllipse(sx - spotWidth/2, sy - spotHeight/2, spotWidth, spotHeight)

				if data.activeSelection() and sel.property('UUID') == data.activeSelection().property('UUID'):
					p.save()
					p.setPen(QPen(Qt.red, 1., Qt.DashLine))
					p.drawLine(sx, prect.top(), sx, prect.bottom())
					p.drawLine(prect.left(), sy, prect.right(), sy)
					p.restore()
					img = self.pixmapForSelection(sel, prect.width())
					p.drawPixmap(QPointF(prect.x(), prect.bottom()+10), img)

	def pixmapForSelection(self, sel, width):
		imgFile = sel.property('Image')
		if not imgFile:
			return QPixmap()

		img = QPixmap(imgFile)
		img = img.scaledToWidth(width)
		p = QPainter(img)
		p.setPen(QPen(Qt.red, 1., Qt.DashLine))
		p.drawLine(0, img.height()/2, img.width(), img.height()/2)
		p.drawLine(img.width()/2, 0, img.width()/2, img.height())
		return img

def createUIElements():
	dock = QDockWidget('Cell View')
	dock.setObjectName('CellViewDock')
	cellView = CellView(dock)
	dock.setWidget(cellView)
	ui.setDock(dock)
	ui.setMenuName(['Tools'])


